==> barcode_reader-0.0.14.tar.gz: android/src/main/java/com/faranegar/barcode_reader/AndroidBarcodeScannerView.java <==
package com.faranegar.barcode_reader;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.graphics.PixelFormat;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.hardware.Camera;
import android.util.Base64;
import android.view.Gravity;
import android.view.View;
import android.view.WindowManager;
import android.widget.FrameLayout;

import androidx.core.content.ContextCompat;

import com.google.zxing.Result;

import java.io.ByteArrayOutputStream;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;

import helperwix.BarcodeScanner2;
import helperwix.CameraView2;
import helperwix.CameraViewManager2;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

import static io.flutter.plugin.common.MethodChannel.MethodCallHandler;

class AndroidBarcodeScannerView implements PlatformView, MethodCallHandler, Camera.PictureCallback {
    private final CameraView2 view;
    private final CameraViewManager2 cameraManager;
    private final MethodChannel methodChannel;
    private ArrayList<Integer> mSelectedIndices;
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            // Do your stuff here

            methodChannel.invokeMethod("barcodeRead", intent.getExtras().getString("Barcode"));
        }
    };
    private MethodChannel.Result result;
    private Activity activity;
    private double scale;
    private int quality;


    AndroidBarcodeScannerView(Activity activity, BinaryMessenger messenger, int id) {
        this.activity = activity;
        cameraManager = new CameraViewManager2();

        view = cameraManager.createViewInstance(activity, new BarcodeScanner2.ResultHandler() {
            @Override
            public void handleResult(Result result) {
                methodChannel.invokeMethod("barcodeRead", result.getText());
            }
        });

        methodChannel = new MethodChannel(messenger, "com.faranegar/androidbarcodescanner_" + id);
        methodChannel.setMethodCallHandler(this);
    }



    @Override
    public View getView() {
        return view;
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {

        switch (methodCall.method) {
            case "initCamera":
                initCamera(methodCall, result);
                break;
            case "pauseCamera":
                pauseCamera(methodCall, result);
                break;
            case "resumeCamera":
                resumeCamera(methodCall, result);
                break;
            case "takePicture":
                takePicture(methodCall, result);
                break;
            default:
                result.notImplemented();
        }

    }

    private Drawable getBackgroundDrawable(int i) {
        int j = 255 - (int) Math.round(255D * Math.exp(4D * ((double) i / 100D) - 4D));
        return new ColorDrawable(Color.argb(j, 0, 0, 0));}

    private void takePicture(MethodCall methodCall, MethodChannel.Result result) {
        this.result = result;
        scale = methodCall.argument("scale");
        quality =  methodCall.argument("quality");
//        try {
//
//
//
//            WindowManager windowManager =  activity.getWindowManager();
//            android.view.WindowManager.LayoutParams layoutParams = new WindowManager.LayoutParams();
//            layoutParams.height = WindowManager.LayoutParams.FILL_PARENT;
//            layoutParams.width = WindowManager.LayoutParams.FILL_PARENT;
//            layoutParams.flags = 280; // You can try LayoutParams.FLAG_FULLSCREEN too
//            layoutParams.format = PixelFormat.TRANSLUCENT; // You can try different formats
//            layoutParams.windowAnimations = android.R.style.Animation_Toast; // You can use only animations that the system to can access
//            layoutParams.type = WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY;
//            layoutParams.gravity = Gravity.BOTTOM;
//            layoutParams.x = 0;
//            layoutParams.y = 0;
//            layoutParams.verticalWeight = 1.0F;
//            layoutParams.horizontalWeight = 1.0F;
//            layoutParams.verticalMargin = 0.0F;
//            layoutParams.horizontalMargin = 0.0F;
//            FrameLayout view = new FrameLayout(activity);
//
//            view.setFocusable(false);
//
//            view.setClickable(false);
//
//            view.setKeepScreenOn(false);
//
//            view.setLongClickable(false);
//
//            view.setFocusableInTouchMode(false);
//
//            view.setBackgroundDrawable(getBackgroundDrawable(0));
//
//            windowManager.addView(view, layoutParams);
//
//
//
//
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
        view.takePicture(this);
    }

    private void resumeCamera(MethodCall methodCall, MethodChannel.Result result) {
//        view.resumeScanning();
        CameraViewManager2.setCameraView(view);
    }

    private void pauseCamera(MethodCall methodCall, MethodChannel.Result result) {
        CameraViewManager2.removeCameraView();
        result.success(null);
    }

    private void initCamera(MethodCall methodCall, MethodChannel.Result result) {

//        view.setId(R.id.zxing_view);

//        fullScannerFragment = new AndroidViewScannerFragment();
//        fullScannerFragment.setResultHandlerListener(new ZXingScannerView.ResultHandler() {
//            @Override
//            public void handleResult(Result rawResult) {
//                activity.runOnUiThread(new Runnable() {
//                    @Override
//                    public void run() {
//                        methodChannel.invokeMethod("barcodeRead", rawResult.getText());
//                    }
//                });
//
//            }
//        });
//
////        fullScannerFragment.show(activity.getFragmentManager(), "");
//        FragmentTransaction transaction = activity.getFragmentManager().beginTransaction();
//        transaction.add(android.R.id.content, fullScannerFragment, "FragmentBarcode");
//        transaction.commit();


//        Intent intent = new Intent(activity, SimpleScannerActivity.class);
//        activity.startActivity(intent);


//        view.setFlash(false);
//        view.setAutoFocus(true);
//
//        view.setResultHandler(new ZXingScannerViewCustom.ResultHandler() {
//            @Override
//            public void handleResult(Result rawResult) {
//                activity.runOnUiThread(new Runnable() {
//                    @Override
//                    public void run() {
//                        methodChannel.invokeMethod("barcodeRead", rawResult.getText());
//                    }
//                });
//            }
//        });
//        view.startCamera();


        result.success(null);

    }


    @Override
    public void dispose() {
    }


    @Override
    public void onPictureTaken(byte[] data, Camera camera) {

        Bitmap bitmap = BitmapFactory.decodeByteArray(data, 0, data.length);
        Bitmap resized = Bitmap.createScaledBitmap(bitmap,(int)(bitmap.getWidth()*scale), (int)(bitmap.getHeight()*scale), true);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        resized.compress(Bitmap.CompressFormat.JPEG, quality, byteArrayOutputStream);
        byte[] byteArray = byteArrayOutputStream .toByteArray();
        result.success(Base64.encodeToString(byteArray, Base64.DEFAULT));
        CameraViewManager2.connectHolder();
    }

}

==> barcode_reader-0.0.15.tar.gz: android/src/main/java/com/faranegar/barcode_reader/AndroidBarcodeScannerView.java <==
package com.faranegar.barcode_reader;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.graphics.PixelFormat;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.hardware.Camera;
import android.util.Base64;
import android.view.Gravity;
import android.view.View;
import android.view.WindowManager;
import android.widget.FrameLayout;

import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.google.zxing.Result;

import java.io.ByteArrayOutputStream;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;

import helperwix.BarcodeScanner2;
import helperwix.CameraView2;
import helperwix.CameraViewManager2;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.platform.PlatformView;

import static io.flutter.plugin.common.MethodChannel.MethodCallHandler;

class AndroidBarcodeScannerView implements PlatformView, MethodCallHandler, Camera.PictureCallback {
    private CameraView2 view;
    private final CameraViewManager2 cameraManager;
    private final MethodChannel methodChannel;
    private ArrayList<Integer> mSelectedIndices;
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            // Do your stuff here

            methodChannel.invokeMethod("barcodeRead", intent.getExtras().getString("Barcode"));
        }
    };
    private MethodChannel.Result result;
    private Activity activity;
    private PluginRegistry.Registrar registrar;
    private double scale;
    private int quality;




    public AndroidBarcodeScannerView(PluginRegistry.Registrar registrar, int id) {
        this.activity = registrar.activity();
        this.registrar = registrar;
        cameraManager = new CameraViewManager2();

        view = cameraManager.createViewInstance(activity, new BarcodeScanner2.ResultHandler() {
            @Override
            public void handleResult(Result result) {
                methodChannel.invokeMethod("barcodeRead", result.getText());
            }
        });

        methodChannel = new MethodChannel(registrar.messenger(), "com.faranegar/androidbarcodescanner_" + id);
        methodChannel.setMethodCallHandler(this);
    }


    @Override
    public View getView() {
        return view;
    }

    private void requestPermission(final MethodChannel.Result result) {
        if (ContextCompat.checkSelfPermission(
                registrar.activity() , android.Manifest.permission.CAMERA) ==
                PackageManager.PERMISSION_GRANTED) {
            // You can use the API that requires the permission.
            result.success(true);
        } else {
            registrar.addRequestPermissionsResultListener(new PluginRegistry.RequestPermissionsResultListener() {
                @Override
                public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
                    switch (requestCode) {
                        case 5505:
                            if (grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                                //granted
                                result.success(true);
                            } else {
                                //not granted
                                if (ActivityCompat.shouldShowRequestPermissionRationale(registrar.activity(), android.Manifest.permission.CAMERA))
                                    requestPermission(result);
                                else //don't ask again clicked
                                    result.success(false);
                            }
                            break;

                    }
                    return true;
                }
            });
            ActivityCompat.requestPermissions(registrar.activity(), new String[]{android.Manifest.permission.CAMERA}, 5505);
        }

    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {

        switch (methodCall.method) {
            case "initCamera":
                initCamera(methodCall, result);
                break;
            case "pauseCamera":
                pauseCamera(result);
                break;
            case "resumeCamera":
                resumeCamera();
                break;
            case "takePicture":
                takePicture(methodCall, result);
                break;
            case "requestPermission":
                requestPermission(result);
                break;


            default:
                result.notImplemented();
        }

    }

    private Drawable getBackgroundDrawable(int i) {
        int j = 255 - (int) Math.round(255D * Math.exp(4D * ((double) i / 100D) - 4D));
        return new ColorDrawable(Color.argb(j, 0, 0, 0));}

    private void takePicture(MethodCall methodCall, MethodChannel.Result result) {
        this.result = result;
        scale = methodCall.argument("scale");
        quality =  methodCall.argument("quality");
//        try {
//
//
//
//            WindowManager windowManager =  activity.getWindowManager();
//            android.view.WindowManager.LayoutParams layoutParams = new WindowManager.LayoutParams();
//            layoutParams.height = WindowManager.LayoutParams.FILL_PARENT;
//            layoutParams.width = WindowManager.LayoutParams.FILL_PARENT;
//            layoutParams.flags = 280; // You can try LayoutParams.FLAG_FULLSCREEN too
//            layoutParams.format = PixelFormat.TRANSLUCENT; // You can try different formats
//            layoutParams.windowAnimations = android.R.style.Animation_Toast; // You can use only animations that the system to can access
//            layoutParams.type = WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY;
//            layoutParams.gravity = Gravity.BOTTOM;
//            layoutParams.x = 0;
//            layoutParams.y = 0;
//            layoutParams.verticalWeight = 1.0F;
//            layoutParams.horizontalWeight = 1.0F;
//            layoutParams.verticalMargin = 0.0F;
//            layoutParams.horizontalMargin = 0.0F;
//            FrameLayout view = new FrameLayout(activity);
//
//            view.setFocusable(false);
//
//            view.setClickable(false);
//
//            view.setKeepScreenOn(false);
//
//            view.setLongClickable(false);
//
//            view.setFocusableInTouchMode(false);
//
//            view.setBackgroundDrawable(getBackgroundDrawable(0));
//
//            windowManager.addView(view, layoutParams);
//
//
//
//
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
        view.takePicture(this);
    }

    private void resumeCamera() {
//        view.resumeScanning();
        CameraViewManager2.setCameraView(view);
    }

    private void pauseCamera(MethodChannel.Result result) {
        CameraViewManager2.removeCameraView();
        result.success(null);
    }

    private void initCamera(MethodCall methodCall, MethodChannel.Result result) {
        result.success(null);
    }


    @Override
    public void dispose() {
    }


    @Override
    public void onPictureTaken(byte[] data, Camera camera) {

        Bitmap bitmap = BitmapFactory.decodeByteArray(data, 0, data.length);
        Bitmap resized = Bitmap.createScaledBitmap(bitmap,(int)(bitmap.getWidth()*scale), (int)(bitmap.getHeight()*scale), true);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        resized.compress(Bitmap.CompressFormat.JPEG, quality, byteArrayOutputStream);
        byte[] byteArray = byteArrayOutputStream .toByteArray();
        result.success(Base64.encodeToString(byteArray, Base64.DEFAULT));
        CameraViewManager2.connectHolder();
    }

}
